==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Netfang");
define("_RE","Re");
define("_SUBJECT","Efni");
define("_PRIVATEMESSAGES","Skilaboahlfi itt");
define("_CHECKALL","Merkja allt");
define("_FROM","Fr");
define("_DATE","Dags");
define("_DONTHAVEMESSAGES","Engin skilabo  hlfinu");
define("_NOTREAD","lesin");
define("_MSGSTATUS","Staa skilabos");
define("_PRIVATEMESSAGE","Skilabo");
define("_INDEX","Yfirlit");
define("_SENT","Sent");
define("_PREVIOUSMESSAGE","Fyrri skilabo");
define("_NEXTMESSAGE","Nstu skilabo");
define("_PROFILE","Notandaupplsingar");
define("_ABOUTPOSTING","Um pstsendingar");
define("_ALLREGCANPOST","Allir skrir notendur geta sent skilabo");
define("_TO","Til");
define("_MESSAGEICON","Tknmynd");
define("_MESSAGE","Skilabo");
define("_HTML","HTML");
define("_PMON","Virkt");
define("_PMOFF","virkt");
define("_BBCODE","BBCode");
define("_WROTE","skrifai");
define("_OPTIONS","Stillingar");
define("_HTMLDISSABLE","Gera HTML virkt");
define("_BBCODEDISSABLE","Gera <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> virkan");
define("_SMILEDISSABLE","Gera <a href=\"bb_smilies.php\" target=\"_blank\"><i>broskalla</i></a> virka");
define("_CANCELREPLY","Htta vi svar");
define("_CANCELSEND","Htta vi a senda");
define("_CLEAR","Hreinsa");
define("_SUBMIT","Senda inn");
define("_USERNOTINDB","Vikomandi notandi er ekki til.");
define("_CHECKNAMEANDTRY","Athugau nafni og reyndu aftur.");
define("_MSGPOSTED","Skilaboin hafa veri send.");
define("_RETURNTOPMSG"," getur smellt hr til a skoa skilaboahlfi itt.");
define("_MSGDELETED","Skilabounum hefur veri eytt.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Netfang");
define("_RE","Re");
define("_SUBJECT","Efni");
define("_PRIVATEMESSAGES","Skilaboahlfi itt");
define("_CHECKALL","Merkja allt");
define("_FROM","Fr");
define("_DATE","Dags");
define("_DONTHAVEMESSAGES","Engin skilabo  hlfinu");
define("_NOTREAD","lesin");
define("_MSGSTATUS","Staa skilabos");
define("_PRIVATEMESSAGE","Skilabo");
define("_INDEX","Yfirlit");
define("_SENT","Sent");
define("_PREVIOUSMESSAGE","Fyrri skilabo");
define("_NEXTMESSAGE","Nstu skilabo");
define("_PROFILE","Notandaupplsingar");
define("_ABOUTPOSTING","Um pstsendingar");
define("_ALLREGCANPOST","Allir skrir notendur geta sent skilabo");
define("_TO","Til");
define("_MESSAGEICON","Tknmynd");
define("_MESSAGE","Skilabo");
define("_HTML","HTML");
define("_PMON","Virkt");
define("_PMOFF","virkt");
define("_BBCODE","BBCode");
define("_WROTE","skrifai");
define("_OPTIONS","Stillingar");
define("_HTMLDISSABLE","Gera HTML virkt");
define("_BBCODEDISSABLE","Gera <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> virkan");
define("_SMILEDISSABLE","Gera <a href=\"bb_smilies.php\" target=\"_blank\"><i>broskalla</i></a> virka");
define("_CANCELREPLY","Htta vi svar");
define("_CANCELSEND","Htta vi a senda");
define("_CLEAR","Hreinsa");
define("_SUBMIT","Senda inn");
define("_USERNOTINDB","Vikomandi notandi er ekki til.");
define("_CHECKNAMEANDTRY","Athugau nafni og reyndu aftur.");
define("_MSGPOSTED","Skilaboin hafa veri send.");
define("_RETURNTOPMSG"," getur smellt hr til a skoa skilaboahlfi itt.");
define("_MSGDELETED","Skilabounum hefur veri eytt.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
